@@ -1,4 +1,4 @@
-def print_lol(the_list):
+def print_lol(the_list,level):
     for each_item in the_list:
         if isinstance(each_item, list):
             print_lol(each_item, level+1)
